==> nattable_1.6.0%2Bdfsg.orig.tar.xz: org.eclipse.nebula.widgets.nattable-1.6.0/org.eclipse.nebula.widgets.nattable.core/src/org/eclipse/nebula/widgets/nattable/grid/data/DefaultCornerDataProvider.java <==
/*******************************************************************************
 * Copyright (c) 2012 Original authors and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Original authors and others - initial API and implementation
 ******************************************************************************/
package org.eclipse.nebula.widgets.nattable.grid.data;

import org.eclipse.nebula.widgets.nattable.data.IDataProvider;

public class DefaultCornerDataProvider implements IDataProvider {

    private final IDataProvider columnHeaderDataProvider;
    private final IDataProvider rowHeaderDataProvider;

    public DefaultCornerDataProvider(IDataProvider columnHeaderDataProvider,
            IDataProvider rowHeaderDataProvider) {
        this.columnHeaderDataProvider = columnHeaderDataProvider;
        this.rowHeaderDataProvider = rowHeaderDataProvider;
    }

    @Override
    public int getColumnCount() {
        return this.rowHeaderDataProvider.getColumnCount();
    }

    @Override
    public int getRowCount() {
        return this.columnHeaderDataProvider.getRowCount();
    }

    @Override
    public Object getDataValue(int columnIndex, int rowIndex) {
        return null;
    }

    @Override
    public void setDataValue(int columnIndex, int rowIndex, Object newValue) {
        throw new UnsupportedOperationException();
    }

}

==> nattable_2.0.0%2Bdfsg.orig.tar.xz: org.eclipse.nebula.widgets.nattable-2.0.0/org.eclipse.nebula.widgets.nattable.core/src/org/eclipse/nebula/widgets/nattable/grid/data/DefaultCornerDataProvider.java <==
/*******************************************************************************
 * Copyright (c) 2012, 2020 Original authors and others.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Original authors and others - initial API and implementation
 ******************************************************************************/
package org.eclipse.nebula.widgets.nattable.grid.data;

import org.eclipse.nebula.widgets.nattable.data.IDataProvider;

public class DefaultCornerDataProvider implements IDataProvider {

    private final IDataProvider columnHeaderDataProvider;
    private final IDataProvider rowHeaderDataProvider;

    public DefaultCornerDataProvider(IDataProvider columnHeaderDataProvider, IDataProvider rowHeaderDataProvider) {
        this.columnHeaderDataProvider = columnHeaderDataProvider;
        this.rowHeaderDataProvider = rowHeaderDataProvider;
    }

    @Override
    public int getColumnCount() {
        return this.rowHeaderDataProvider.getColumnCount();
    }

    @Override
    public int getRowCount() {
        return this.columnHeaderDataProvider.getRowCount();
    }

    @Override
    public Object getDataValue(int columnIndex, int rowIndex) {
        return null;
    }

    @Override
    public void setDataValue(int columnIndex, int rowIndex, Object newValue) {
        throw new UnsupportedOperationException();
    }

}
